from .score import score
from .score_v1 import score_v1

METADATA = {
    "name": "genetic_manipulation",
    "category": "genetic_manipulation",
    "display_name": "Genetic Manipulation: CRISPR",
    "display_name_short": "CRISPR",
    "description": "Genetic manipulation techniques (e.g., CRISPR gene editing)",
    "pass_threshold": 70,
    "requires_reference": False,
    "options_schema": None,
    "deprecated": True,
}
