_DEFAULT_WEIGHTS = {
    'ngram': 0.15,  # N-gram Analysis (15%)
    'fingerprint': 0.15,  # Fingerprinting (15%)
    'sentence': 0.50,  # Sentence-level Analysis (50%)
    'ast': 0.05,  # AST Comparison (5%)
    'sequence': 0.10,  # Sequence Matching (10%)
    'jaccard': 0.05  # Jaccard Similarity (5%)
}
